@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getEvalInfo(vmanage, deviceId):
     """
     Get license evaluation info from device
@@ -14,8 +11,8 @@ def getEvalInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/license/evaluation?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/license/evaluation?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getPAKInfo(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def getPAKInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/license/pak?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/license/pak?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getPrivacyInfo(vmanage, deviceId):
     """
@@ -46,8 +43,8 @@ def getPrivacyInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/license/privacy?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/license/privacy?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getRegInfo(vmanage, deviceId):
     """
@@ -62,8 +59,8 @@ def getRegInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/license/registration?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/license/registration?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getUDIInfo(vmanage, deviceId):
     """
@@ -78,8 +75,8 @@ def getUDIInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/license/udi?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/license/udi?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getUsageInfo(vmanage, deviceId):
     """
@@ -94,6 +91,6 @@ def getUsageInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/license/usage?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/license/usage?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
