@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def sleauthenticate(vmanage, partner):
     """
     authenticate user for sle
@@ -14,8 +11,8 @@ def sleauthenticate(vmanage, partner):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/smartLicensing/authenticate"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, partner)
+    endpoint = f"dataservice/smartLicensing/authenticate"
+    response = vmanage.apiCall("POST", endpoint, partner)
     return response
 def fetchAccounts(vmanage, partner, mode):
     """
@@ -31,8 +28,8 @@ def fetchAccounts(vmanage, partner, mode):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/smartLicensing/fetchAccounts?mode={mode}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint, partner)
+    endpoint = f"dataservice/smartLicensing/fetchAccounts?mode={mode}"
+    response = vmanage.apiCall("GET", endpoint, partner)
     return response
 def fetchReports(vmanage, partner):
     """
@@ -47,8 +44,8 @@ def fetchReports(vmanage, partner):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/smartLicensing/fetchAllSa"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint, partner)
+    endpoint = f"dataservice/smartLicensing/fetchAllSa"
+    response = vmanage.apiCall("GET", endpoint, partner)
     return response
 def fetchReports(vmanage, partner, saDomain, saId):
     """
@@ -65,8 +62,8 @@ def fetchReports(vmanage, partner, saDomain, saId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/smartLicensing/fetchReportsForSa?saDomain={saDomain}&saId={saId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint, partner)
+    endpoint = f"dataservice/smartLicensing/fetchReportsForSa?saDomain={saDomain}&saId={saId}"
+    response = vmanage.apiCall("GET", endpoint, partner)
     return response
 def getUserSettings(vmanage):
     """
@@ -80,8 +77,8 @@ def getUserSettings(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/smartLicensing/getUserSettings"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/smartLicensing/getUserSettings"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def syncLicenses(vmanage, partner):
     """
@@ -96,8 +93,8 @@ def syncLicenses(vmanage, partner):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/smartLicensing/removeSaVaSelection"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, partner)
+    endpoint = f"dataservice/smartLicensing/removeSaVaSelection"
+    response = vmanage.apiCall("POST", endpoint, partner)
     return response
 def syncLicenses(vmanage, partner):
     """
@@ -112,8 +109,8 @@ def syncLicenses(vmanage, partner):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/smartLicensing/syncLicenses"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, partner)
+    endpoint = f"dataservice/smartLicensing/syncLicenses"
+    response = vmanage.apiCall("POST", endpoint, partner)
     return response
 def uploadAck(vmanage, partner):
     """
@@ -128,6 +125,6 @@ def uploadAck(vmanage, partner):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/smartLicensing/uploadAck"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, partner)
+    endpoint = f"dataservice/smartLicensing/uploadAck"
+    response = vmanage.apiCall("POST", endpoint, partner)
     return response
